@@ -15,18 +15,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""
-Linear time-variant model predictive control in Python.
-"""
+"""Linear time-variant model predictive control in Python."""
 
-from .problem import Problem
-from .solution import Solution
+from .mpc_problem import MPCProblem
+from .mpc_qp import MPCQP
+from .plan import Plan
 from .solve_mpc import solve_mpc
 
 __all__ = [
-    "Problem",
-    "Solution",
+    "MPCProblem",
+    "MPCQP",
+    "Plan",
     "solve_mpc",
 ]
 
-__version__ = "1.0.0"
+__version__ = "2.0.0"
